@@ -157,10 +157,6 @@ def raise_(exception: BaseException) -> Any:
     raise exception
 
 
-def transplant_path(dir_from: Path, dir_to: Path, path: Path) -> Path:
-    return dir_to.joinpath(path.relative_to(dir_from))
-
-
 @overload
 def async_cached(
     fn: Callable[[], Coroutine[Any, Any, T]]
